@@ -14,11 +14,11 @@
 #    under the License.
 
 import hashlib
+import io
 from unittest import mock
 
 from oslo_utils.secretutils import md5
 from oslo_utils import units
-import six
 
 from glance_store._drivers import rbd as rbd_store
 from glance_store import exceptions
@@ -173,6 +173,9 @@ class MockRBD(object):
         def clone(self, *args, **kwargs):
             raise NotImplementedError()
 
+        def trash_move(self, *args, **kwargs):
+            pass
+
     RBD_FEATURE_LAYERING = 1
 
 
@@ -210,10 +213,10 @@ class TestReSize(base.StoreBaseTest,
                 data_len_temp = data_len
                 resize_amount = self.store.WRITE_CHUNKSIZE
                 while data_len_temp > 0:
+                    resize_amount *= 2
                     expected_calls.append(resize_amount + (data_len -
                                                            data_len_temp))
                     data_len_temp -= resize_amount
-                    resize_amount *= 2
                     expected += 1
                 self.assertEqual(expected, resize.call_count)
                 resize.assert_has_calls([mock.call(call) for call in
@@ -241,7 +244,7 @@ class TestReSize(base.StoreBaseTest,
         # Current size is smaller than we need
         self.store.size = 8
         ret = self.store._resize_on_write(image, 0, 16, 16)
-        self.assertEqual(8 + self.store.WRITE_CHUNKSIZE, ret)
+        self.assertEqual(8 + self.store.WRITE_CHUNKSIZE * 2, ret)
         self.assertEqual(self.store.WRITE_CHUNKSIZE * 2,
                          self.store.resize_amount)
         image.resize.assert_called_once_with(ret)
@@ -250,47 +253,55 @@ class TestReSize(base.StoreBaseTest,
         image.resize.reset_mock()
         self.store.size = ret
         ret = self.store._resize_on_write(image, 0, 64, 16)
-        self.assertEqual(8 + self.store.WRITE_CHUNKSIZE, ret)
+        self.assertEqual(8 + self.store.WRITE_CHUNKSIZE * 2, ret)
         image.resize.assert_not_called()
 
         # Read past the limit triggers another resize
         ret = self.store._resize_on_write(image, 0, ret + 1, 16)
-        self.assertEqual(8 + self.store.WRITE_CHUNKSIZE * 3, ret)
+        self.assertEqual(8 + self.store.WRITE_CHUNKSIZE * 6, ret)
         image.resize.assert_called_once_with(ret)
         self.assertEqual(self.store.WRITE_CHUNKSIZE * 4,
                          self.store.resize_amount)
 
         # Check that we do not resize past the 8G ceiling.
 
-        # Start with resize_amount at 4G, 1G read so far
+        # Start with resize_amount at 2G, 1G read so far
         image.resize.reset_mock()
-        self.store.resize_amount = 4 * units.Gi
+        self.store.resize_amount = 2 * units.Gi
         self.store.size = 1 * units.Gi
 
-        # First resize happens and we get the 4G,
-        # resize_amount goes to limit of 8G
+        # First resize happens and we get to 5G,
+        # resize_amount goes to limit of 4G
         ret = self.store._resize_on_write(image, 0, 4097 * units.Mi, 16)
-        self.assertEqual(5 * units.Gi, ret)
-        self.assertEqual(8 * units.Gi, self.store.resize_amount)
+        self.assertEqual(4 * units.Gi, self.store.resize_amount)
+        self.assertEqual((1 + 4) * units.Gi, ret)
         self.store.size = ret
 
-        # Second resize happens and we get to 13G,
+        # Second resize happens and we stay at 13, no resize
         # resize amount stays at limit of 8G
         ret = self.store._resize_on_write(image, 0, 6144 * units.Mi, 16)
-        self.assertEqual((5 + 8) * units.Gi, ret)
         self.assertEqual(8 * units.Gi, self.store.resize_amount)
+        self.assertEqual((1 + 4 + 8) * units.Gi, ret)
         self.store.size = ret
 
-        # Third resize happens and we get to 21G,
+        # Third resize happens and we get to 21,
         # resize amount stays at limit of 8G
         ret = self.store._resize_on_write(image, 0, 14336 * units.Mi, 16)
-        self.assertEqual((5 + 8 + 8) * units.Gi, ret)
         self.assertEqual(8 * units.Gi, self.store.resize_amount)
+        self.assertEqual((1 + 4 + 8 + 8) * units.Gi, ret)
+        self.store.size = ret
+
+        # Fourth resize happens and we get to 29,
+        # resize amount stays at limit of 8G
+        ret = self.store._resize_on_write(image, 0, 22528 * units.Mi, 16)
+        self.assertEqual(8 * units.Gi, self.store.resize_amount)
+        self.assertEqual((1 + 4 + 8 + 8 + 8) * units.Gi, ret)
 
         image.resize.assert_has_calls([
             mock.call(5 * units.Gi),
             mock.call(13 * units.Gi),
-            mock.call(21 * units.Gi)])
+            mock.call(21 * units.Gi),
+            mock.call(29 * units.Gi)])
 
 
 class TestStore(base.StoreBaseTest,
@@ -315,7 +326,7 @@ class TestStore(base.StoreBaseTest,
                                                 self.conf)
         # Provide enough data to get more than one chunk iteration.
         self.data_len = 3 * units.Ki
-        self.data_iter = six.BytesIO(b'*' * self.data_len)
+        self.data_iter = io.BytesIO(b'*' * self.data_len)
         self.hash_algo = 'sha256'
 
     def test_thin_provisioning_is_disabled_by_default(self):
@@ -409,7 +420,7 @@ class TestStore(base.StoreBaseTest,
         image_id = 'fake_image_id'
         file_size = 5 * units.Ki  # 5K
         file_contents = b"*" * file_size
-        image_file = six.BytesIO(file_contents)
+        image_file = io.BytesIO(file_contents)
 
         with mock.patch.object(rbd_store.rbd.Image, 'write'):
             self.store.add(image_id, image_file, file_size, self.hash_algo,
@@ -422,7 +433,7 @@ class TestStore(base.StoreBaseTest,
         image_id = 'fake_image_id'
         file_size = 5 * units.Ki  # 5K
         file_contents = b"*" * file_size
-        image_file = six.BytesIO(file_contents)
+        image_file = io.BytesIO(file_contents)
         expected_checksum = md5(file_contents,
                                 usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(file_contents).hexdigest()
@@ -496,7 +507,7 @@ class TestStore(base.StoreBaseTest,
         self.store.configure()
 
         image_id = 'fake_image_id'
-        image_file = six.BytesIO(content)
+        image_file = io.BytesIO(content)
         expected_checksum = md5(content,
                                 usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(content).hexdigest()
@@ -633,37 +644,51 @@ class TestStore(base.StoreBaseTest,
         with mock.patch.object(MockRBD.Image, 'list_children') as mocked:
             mocked.return_value = True
 
-            self.assertRaises(exceptions.InUseByStore,
-                              self.store._delete_image,
-                              'fake_pool', self.location.image,
-                              snapshot_name='snap')
+            self.store._delete_image('fake_pool',
+                                     self.location.image,
+                                     snapshot_name='snap')
 
     def test_delete_image_w_snap_exc_image_has_snap(self):
         def _fake_remove(*args, **kwargs):
             self.called_commands_actual.append('remove')
             raise MockRBD.ImageHasSnapshots()
 
+        mock.patch.object(MockRBD.RBD, 'trash_move').start()
+
         with mock.patch.object(MockRBD.RBD, 'remove') as remove:
             remove.side_effect = _fake_remove
-            self.assertRaises(exceptions.HasSnapshot, self.store._delete_image,
-                              'fake_pool', self.location.image)
+            self.store._delete_image('fake_pool',
+                                     self.location.image)
 
             self.called_commands_expected = ['remove']
 
+        MockRBD.RBD.trash_move.assert_called_once_with(mock.ANY, 'fake_image')
+
+    def test_delete_image_w_snap_exc_image_has_snap_2(self):
+        def _fake_remove(*args, **kwargs):
+            self.called_commands_actual.append('remove')
+            raise MockRBD.ImageHasSnapshots()
+
+        mock.patch.object(MockRBD.RBD, 'trash_move',
+                          side_effect=MockRBD.ImageBusy).start()
+
+        with mock.patch.object(MockRBD.RBD, 'remove') as remove:
+            remove.side_effect = _fake_remove
+            self.assertRaises(exceptions.InUseByStore,
+                              self.store._delete_image,
+                              'fake_pool',
+                              self.location.image)
+
+            self.called_commands_expected = ['remove']
+
+        MockRBD.RBD.trash_move.assert_called_once_with(mock.ANY, 'fake_image')
+
     def test_get_partial_image(self):
         loc = g_location.Location('test_rbd_store', rbd_store.StoreLocation,
                                   self.conf, store_specs=self.store_specs)
         self.assertRaises(exceptions.StoreRandomGetNotSupported,
                           self.store.get, loc, chunk_size=1)
 
-    @mock.patch.object(MockRados.Rados, 'connect')
-    def test_rados_connect_timeout(self, mock_rados_connect):
-        socket_timeout = 1
-        self.config(rados_connect_timeout=socket_timeout)
-        self.store.configure()
-        with self.store.get_connection('conffile', 'rados_id'):
-            mock_rados_connect.assert_called_with(timeout=socket_timeout)
-
     @mock.patch.object(MockRados.Rados, 'connect', side_effect=MockRados.Error)
     def test_rados_connect_error(self, _):
         rbd_store.rados.Error = MockRados.Error
@@ -700,3 +725,67 @@ class TestStore(base.StoreBaseTest,
         self.assertEqual(self.called_commands_expected,
                          self.called_commands_actual)
         super(TestStore, self).tearDown()
+
+    @mock.patch('oslo_utils.eventletutils.is_monkey_patched')
+    def test_create_image_in_native_thread(self, mock_patched):
+        mock_patched.return_value = True
+        # Tests that we use non-0 features from ceph.conf and cast to int.
+        fsid = 'fake'
+        features = '3'
+        conf_get_mock = mock.Mock(return_value=features)
+        conn = mock.Mock(conf_get=conf_get_mock)
+        ioctxt = mock.sentinel.ioctxt
+        name = '1'
+        size = 1024
+        order = 3
+        fake_proxy = mock.MagicMock()
+        fake_rbd = mock.MagicMock()
+
+        with mock.patch.object(rbd_store.tpool, 'Proxy') as tpool_mock, \
+                mock.patch.object(rbd_store.rbd, 'RBD') as rbd_mock:
+            tpool_mock.return_value = fake_proxy
+            rbd_mock.return_value = fake_rbd
+            location = self.store._create_image(
+                fsid, conn, ioctxt, name, size, order)
+            self.assertEqual(fsid, location.specs['fsid'])
+            self.assertEqual(rbd_store.DEFAULT_POOL, location.specs['pool'])
+            self.assertEqual(name, location.specs['image'])
+            self.assertEqual(rbd_store.DEFAULT_SNAPNAME,
+                             location.specs['snapshot'])
+
+        tpool_mock.assert_called_once_with(fake_rbd)
+        fake_proxy.create.assert_called_once_with(ioctxt, name, size, order,
+                                                  old_format=False, features=3)
+
+    @mock.patch('oslo_utils.eventletutils.is_monkey_patched')
+    def test_delete_image_in_native_thread(self, mock_patched):
+        mock_patched.return_value = True
+        fake_proxy = mock.MagicMock()
+        fake_rbd = mock.MagicMock()
+        fake_ioctx = mock.MagicMock()
+
+        with mock.patch.object(rbd_store.tpool, 'Proxy') as tpool_mock, \
+                mock.patch.object(rbd_store.rbd, 'RBD') as rbd_mock, \
+                mock.patch.object(self.store, 'get_connection') as mock_conn:
+
+            mock_get_conn = mock_conn.return_value.__enter__.return_value
+            mock_ioctx = mock_get_conn.open_ioctx.return_value.__enter__
+            mock_ioctx.return_value = fake_ioctx
+            tpool_mock.return_value = fake_proxy
+            rbd_mock.return_value = fake_rbd
+
+            self.store._delete_image('fake_pool', self.location.image)
+
+            tpool_mock.assert_called_once_with(fake_rbd)
+            fake_proxy.remove.assert_called_once_with(fake_ioctx,
+                                                      self.location.image)
+
+    @mock.patch.object(rbd_store, 'rbd')
+    @mock.patch.object(rbd_store, 'tpool')
+    @mock.patch('oslo_utils.eventletutils.is_monkey_patched')
+    def test_rbd_proxy(self, mock_patched, mock_tpool, mock_rbd):
+        mock_patched.return_value = False
+        self.assertEqual(mock_rbd.RBD(), self.store.RBDProxy())
+
+        mock_patched.return_value = True
+        self.assertEqual(mock_tpool.Proxy.return_value, self.store.RBDProxy())
